@@ -7,6 +7,7 @@ from ..contiguity import Queen, Rook
 from ...io.fileio import FileIO as psopen
 from ... import examples
 import numpy as np
+import scipy
 import unittest
 
 
@@ -34,6 +35,7 @@ class Testutil(unittest.TestCase):
         w9 = util.lat2SW(3, 3)
         rows, cols = w9.shape
         n = rows * cols
+        self.assertEqual(w9.nnz, 24)
         pct_nonzero = w9.nnz / float(n)
         self.assertEqual(pct_nonzero, 0.29629629629629628)
         data = w9.todense().tolist()
@@ -345,12 +347,16 @@ class Testutil(unittest.TestCase):
         wf = fuzzy_contiguity(rs_df)
         self.assertEqual(wf.islands, [])
         self.assertEqual(set(wf.neighbors[0]), set([239, 59, 152, 23]))
-        buff = fuzzy_contiguity(rs_df, buffering=True, buffer=.2)
-        self.assertEqual(set(buff.neighbors[0]), set([175, 119, 239, 59, 152, 246, 23, 107]))
-        rs_index = rs_df.set_index('NM_MUNICIP')
+        buff = fuzzy_contiguity(rs_df, buffering=True, buffer=0.2)
+        self.assertEqual(
+            set(buff.neighbors[0]), set([175, 119, 239, 59, 152, 246, 23, 107])
+        )
+        rs_index = rs_df.set_index("NM_MUNICIP")
         index_w = fuzzy_contiguity(rs_index)
-        self.assertEqual(set(index_w.neighbors['TAVARES']), set(['SÃO JOSÉ DO NORTE', 'MOSTARDAS']))
-        wf_pred = fuzzy_contiguity(rs_df, predicate='touches')
+        self.assertEqual(
+            set(index_w.neighbors["TAVARES"]), set(["SÃO JOSÉ DO NORTE", "MOSTARDAS"])
+        )
+        wf_pred = fuzzy_contiguity(rs_df, predicate="touches")
         self.assertEqual(set(wf_pred.neighbors[0]), set([]))
         self.assertEqual(set(wf_pred.neighbors[1]), set([142, 82, 197, 285, 386, 350]))
 
